package com.ruoyi.model.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.model.domain.AppletOrderItem;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 订单信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface AppletOrderItemMapper extends BaseMapper<AppletOrderItem>
{
    /**
     * 查询订单信息
     * 
     * @param id 订单信息主键
     * @return 订单信息
     */
    public AppletOrderItem selectAppletOrderItemById(Long id);
    public AppletOrderItem selectAppletOrderItemByOrderIdUserId(@Param("orderId") Long orderId, @Param("userId")Long userId);
    public AppletOrderItem selectAppletOrderItemByOrderId(Long orderId);

    /**
     * 查询订单信息列表
     * 
     * @param AppletOrderItem 订单信息
     * @return 订单信息集合
     */
    public List<AppletOrderItem> selectAppletOrderItemList(AppletOrderItem AppletOrderItem);
    public List<AppletOrderItem> selectAppletOrderItemListLikeUserIdJson(AppletOrderItem AppletOrderItem);

    /**
     * 新增订单信息
     * 
     * @param AppletOrderItem 订单信息
     * @return 结果
     */
    public int insertAppletOrderItem(AppletOrderItem AppletOrderItem);

    /**
     * 修改订单信息
     * 
     * @param AppletOrderItem 订单信息
     * @return 结果
     */
    public int updateAppletOrderItem(AppletOrderItem AppletOrderItem);

    /**
     * 删除订单信息
     * 
     * @param id 订单信息主键
     * @return 结果
     */
    public int deleteAppletOrderItemById(Long id);

    /**
     * 批量删除订单信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletOrderItemByIds(Long[] ids);
}
